[serialization_lib] Align to Tosa Spec

removed attributes for Reshape, Slice and Tile Ops
renamed field accum_dtype to acc_type,
renamed then_branch/else_branch to then_graph/else_graph
renamed cond_branch/body_branch to cond_graph/body_graph

Signed-off-by: Tai Ly <tai.ly@arm.com>
Change-Id: I2001f19519987d9e64c18b1f11762f9d3b9be4ec
diff --git a/include/tosa_serialization_handler.h b/include/tosa_serialization_handler.h
index 715270b..f50d7ad 100644
--- a/include/tosa_serialization_handler.h
+++ b/include/tosa_serialization_handler.h
@@ -127,8 +127,8 @@
         if (major_match && minor_match && patch_match && draft_match)
             return TosaVersion::compat_t::COMPLETELY_COMPATIBLE;
 
-        // We currently support backward compatibility starting from 0.90.0
-        if ((tosa_fb_version._major == 0 && tosa_fb_version._minor >= 90) || (tosa_fb_version._major > 0))
+        // We currently support backward compatibility starting from 0.100.0
+        if ((tosa_fb_version._major == 0 && tosa_fb_version._minor >= 100) || (tosa_fb_version._major > 0))
         {
             if (less_than(tosa_fb_version, serializer_version))
             {